cgdat.cgdat — CGDAT 2.0.0-2-g2917492 documentation

# cgdat.cgdat

This file contains the main GUI class that is used in the Conditional game data analyse tool (CGDAT) was created for a friend of mine to help him with the data analysis he had to do for his graduation project. This tool is licensed under the GPL open source license. You are therefore free use the source code in any way provided that you the original copyright statements.

Classes

`DataAnalyserGUI` | This is the qt class used to create the general user interface for the CGDAT data analysis tool.